CompressedRistretto

Struct CompressedRistretto 

pub struct CompressedRistretto(pub [u8; 32]);
A Ristretto point, in compressed wire format.

The Ristretto encoding is canonical, so two points are equal if and only if their encodings are equal.

Tuple Fields

0: [u8; 32]

Implementations

Source

impl CompressedRistretto

pub const fn to_bytes(&self) -> [u8; 32]

Copy the bytes of this CompressedRistretto.

pub const fn as_bytes(&self) -> &[u8; 32]

View this CompressedRistretto as an array of bytes.

pub fn from_slice( bytes: &[u8], ) -> Result<CompressedRistretto, TryFromSliceError>

Construct a CompressedRistretto from a slice of bytes.

Errors

Returns TryFromSliceError if the input bytes slice does not have a length of 32.

pub fn decompress(&self) -> Option<RistrettoPoint>

Attempt to decompress to an RistrettoPoint.

Return
  • Some(RistrettoPoint) if self was the canonical encoding of a point;

  • None if self was not the canonical encoding of a point.